@@ -8,7 +8,7 @@ $self = {
                       'Pango'
                     ],
           'inc' => '-I/usr/include/librsvg-2.0 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/gdk-pixbuf-2.0 -D_REENTRANT -I/usr/include/libpng16 -I/usr/include/cairo -I/usr/include/pixman-1 -I/usr/include/freetype2 -I/usr/include/uuid ',
-          'libs' => '-lrsvg-2 -lm -lgio-2.0 -lgdk_pixbuf-2.0 -lgobject-2.0 -lglib-2.0 -lintl -l:libcairo.dll.a ',
+          'libs' => '-lrsvg-2 -lm -lgio-2.0 -lgdk_pixbuf-2.0 -lgobject-2.0 -lglib-2.0 -lintl -lcairo ',
           'typemaps' => [
                           'rsvg.typemap',
                           'rsvg2perl.typemap'
